// OTChooser.h

// By Alex B. Cone, Objective Technologies, Inc
// Copyright (c) 1990, 1991 Objective Technologies, Inc.

#import <appkit/Control.h>
#import <appkit/Matrix.h>
#import <objc/List.h>
#import "OTTitleView.h"
#import "OTChooserCell.h"

#define OTCHOOSER_CURRENT_VERSION 10

@interface OTChooser:Control
{
    id	titleView;			// The scrollable subview containing the title and
    						//  the matrix of selection cells.
    id	matrix;				// The matrix of selection cells which is the 
    						//  docView of the titleView.
    float lineHeight;		// The height of each line.
    float interCellHeight;	// The distance between each line.
    int numVisibleLines;	// The # of lines visible in the selection area.
    id	target;				// The object to notify of a Chooser selection.
    SEL action;				// The message sent to the target in the event of a
    						//  Chooser selection.
    SEL doubleAction;		// The message sent in the event of a double click 
    						//  on a selection item.
}

/* METHOD TYPES
 * Intializing the Chooser Factory
 * Creating and Freeing a Chooser
 * Creating a new Cell
 * Laying out the Chooser
 * Modifying the Chooser
 * Selecting and Identifying Cells
 * Target and Action
 * Window Delegation
 * Matrix Delegation
 * Handling Events
 * Displaying
 * Archiving
 */

/* CLASS METHODS */
+ initialize;
+ setCellClass:factoryID;
+ setMatrixClass:factoryID;

/* INSTANCE METHODS */

/* set-up */
- initFrame:(const NXRect *)frameRect;
- initFrame:(const NXRect *)aRect titles:(BOOL)t;
- initFrame:(const NXRect *)aRect titles:(BOOL)t cellClass:factoryID;
- initFrame:(const NXRect *)aRect titles:(BOOL)t prototype:prototypeCell;
- initFrame:(const NXRect *)aRect titles:(BOOL)t matrixClass:aMatrixFactory cellClass:aCellFactory;
- initFrame:(const NXRect *)aRect titles:(BOOL)t matrixClass:aMatrixFactory prototype:prototypeCell;
- free;
- clear;
- setCellClass:factoryID;
- prototype;
- setPrototype:anObject;
- target;
- setTarget:anObject;
- (SEL) action;
- setAction:(SEL) sel;
- (SEL) doubleAction;
- setDoubleAction:(SEL) sel;
- setTitled:(BOOL) yesOrNo;
- (BOOL)titled;
- setUnselectVisible:(BOOL)yesOrNo;
- setIconVisible:(BOOL)yesOrNo;
- setTagVisible:(BOOL)yesOrNo;
- setTitle:(const char *)aString;
- (const char *)title;
- setMode:(int) modeNum;
- (int)mode;

/* selecting and identifying cells */
- titleView;
- cellList;
- cellMatrix;
- (int)rows;
- (int)cols;
- (int) selectedRow;
- selectedCell;
- cellAt:(int)row;
- selectCellAt:(int)row :(int)col;
- selectRowAt:(int)row;
- removeRowAt:(int)row;
- selectAll:sender;

/* laying out the chooser contents */
- addStringAtEnd:(const char *)aString;  // default cell w/ string
- takeStringValueFrom:sender;  // add default cell w/ string at end
- loadStrings:(const char **)stringArray count:(int)numStrings title:(const char *)aTitle;
- addCellAtEnd:aCell;
- addCell:aCell at:(int)row;
- putCell:aCell at:(int)row;

/* target action methods */
- removeSelectedCell:sender;
- selectCell:aCell;
- scrollRowToVisible:(int)row;
- selectNext:sender;
- selectPrev:sender;

- doubleClickMatrix:sender;  // received from matrix when doubleClick occurs
- clickMatrix:sender;  // received from matrix when click occurs
- sizeTo:(float)w :(float) h;
- sizeToFit;
- drawSelf:(const NXRect *)r :(int) c;
- (BOOL) acceptsFirstMouse;
- write:(NXTypedStream *) s;
- read:(NXTypedStream *) s;

/* DELEGATION METHODS */
- windowWillResize:sender toSize:(NXSize *)frameSize;
- windowDidResize:sender;

/* INTERNAL METHODS */
- setUpMatrix;
- resizeCells;

/* IB Inspector */
- (const char*)getInspectorClassName;

@end
